@@ -42,6 +42,7 @@ class NumerousApp():
         self.allow_hibernation = False
         self.start_time = None
         self.end_time = None
+        self.scenarioname = None
         self.max_restarts = max_restarts
         self.status = 0
         self.logger = logging.getLogger(self.appname)
@@ -90,14 +91,14 @@ class NumerousApp():
 
         self.start_time = self.client.run_settings.start.timestamp()
         self.end_time = self.client.run_settings.end.timestamp()
-        self.appname = self.scenario['scenarioName']
+        self.scenarioname = self.scenario['scenarioName']
         self.allow_hibernation = self.client.params.get('allow_hibernation', False)
         self.logger.info(f'allow hibernation: {self.allow_hibernation}')
         self.client._job_id = org_job_id
 
     def loop(self):
 
-        self.logger.info(f'starting numerous app for {self.appname}')
+        self.logger.info(f'starting numerous app for {self.appname} on scenario {self.scenarioname}')
         thread = Thread(target=self.numerous_job._start, args=(self,), daemon=False)
         thread.start()
         starttime = datetime.datetime.now()
